==> security-engine-starter-1.1.1-sources.jar: digital/nedra/commons/starter/security/engine/core/AuthorityConfigurer.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.security.engine.core;

import lombok.AccessLevel;
import lombok.Getter;
import lombok.Setter;

public interface AuthorityConfigurer {

  ContextConfigure context();

  RoleBuilder forbidden();

  RoleBuilder and();

  RoleHandler build();

  @Setter(AccessLevel.PACKAGE)
  @Getter(AccessLevel.PACKAGE)
  class DefaultAuthorityConfigurer implements AuthorityConfigurer {

    String name;
    boolean available = true;
    Fields fields;
    RoleBuilder parent;

    @Override
    public ContextConfigure context() {
      final ContextConfigure.DefaultContextConfigure
          configure = new ContextConfigure.DefaultContextConfigure();
      configure.setParent(parent);
      return configure;
    }

    @Override
    public RoleBuilder forbidden() {
      this.available = false;
      return this.parent.and();
    }

    @Override
    public RoleBuilder and() {
      return this.parent.and();
    }

    @Override
    public RoleHandler build() {
      this.parent.and();
      return this.parent.build();
    }

  }
}

==> security-engine-starter-2.0.2-sources.jar: digital/nedra/commons/starter/security/engine/core/AuthorityConfigurer.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.security.engine.core;

import lombok.AccessLevel;
import lombok.Getter;
import lombok.Setter;

public interface AuthorityConfigurer {

  ContextConfigure context();

  RoleBuilder forbidden();

  RoleBuilder and();

  RoleHandler build();

  @Setter(AccessLevel.PACKAGE)
  @Getter(AccessLevel.PACKAGE)
  class DefaultAuthorityConfigurer implements AuthorityConfigurer {

    String name;
    boolean available = true;
    Fields fields;
    RoleBuilder parent;

    @Override
    public ContextConfigure context() {
      final var configure = new ContextConfigure.DefaultContextConfigure();
      configure.setParent(parent);
      return configure;
    }

    @Override
    public RoleBuilder forbidden() {
      this.available = false;
      return this.parent.and();
    }

    @Override
    public RoleBuilder and() {
      return this.parent.and();
    }

    @Override
    public RoleHandler build() {
      this.parent.and();
      return this.parent.build();
    }

  }
}
